Choo-Siow homoskedastic - Cupid Matching

Skip to content

# `choo_siow` module

The components of the derivative of the entropy for the Choo and Siow homoskedastic model.

## `e0_fun_choo_siow(muhat)`

Returns the values of e_0
for the Choo and Siow model.

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`np.ndarray` | the (X,Y) matrix of the first derivative of the entropy

Source code in `cupid_matching/choo_siow.py`

    145
    146
    147
    148
    149
    150
    151
    152
    153
    154
    155
    def e0_fun_choo_siow(muhat: Matching) -> np.ndarray:
        """Returns the values of $e_0$ for the Choo and Siow model.

        Args:
            muhat: a Matching

        Returns:
            the (X,Y) matrix of the first derivative of the entropy
        """
        entropy_res = _entropy_choo_siow(muhat, deriv=1)
        return entropy_res[1]

## `e0_fun_choo_siow_corrected(muhat)`

Returns the values of e_0
for the Choo and Siow model, using the finite-sample correction log(p+(1-p)/(2N))

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`np.ndarray` | the (X,Y) matrix of the first derivative of the entropy

Source code in `cupid_matching/choo_siow.py`

    158
    159
    160
    161
    162
    163
    164
    165
    166
    167
    168
    169
    170
    def e0_fun_choo_siow_corrected(muhat: Matching) -> np.ndarray:
        """Returns the values of $e_0$ for the Choo and Siow model,
        using the finite-sample correction log(p+(1-p)/(2N))

        Args:
            muhat: a Matching

        Returns:
            the (X,Y) matrix of the first derivative of the entropy
        """
        e0_val_corrected \
            = _der_entropy_choo_siow_corrected(muhat, hessian=False)
        return e0_val_corrected

## `hessian_mumu_choo_siow(muhat)`

Returns the derivatives of e_0
in \mu
for the Choo and Siow model.

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`ThreeArrays` | the three components of the hessian wrt (\mu,\mu) of the entropy

Source code in `cupid_matching/choo_siow.py`

    173
    174
    175
    176
    177
    178
    179
    180
    181
    182
    183
    184
    185
    186
    187
    188
    189
    190
    191
    192
    193
    194
    195
    196
    def hessian_mumu_choo_siow(muhat: Matching) -> ThreeArrays:
        """Returns the derivatives of $e_0$ in $\\mu$
        for the Choo and Siow model.

        Args:
            muhat: a Matching

        Returns:
            the three components of the hessian wrt $(\\mu,\\mu)$ of the entropy
        """
        entropy_res = _entropy_choo_siow(muhat, deriv=2)
        hessmumu = entropy_res[2]
        muxy, *_ = muhat.unpack()
        X, Y = muxy.shape
        hess_x = np.zeros((X, Y, Y))
        hess_y = np.zeros((X, Y, X))
        hess_xy = np.zeros((X, Y))
        for x in range(X):
            for y in range(Y):
                d2xy = hessmumu[x, y, :, :]
                hess_x[x, y, :] = d2xy[x, :]
                hess_y[x, y, :] = d2xy[:, y]
                hess_xy[x, y] = d2xy[x, y]
        return hess_x, hess_y, hess_xy

## `hessian_mumu_choo_siow_corrected(muhat)`

Returns the derivatives of e_0
in \mu
for the Choo and Siow model, with the small sample correction

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`ThreeArrays` | the three components of the hessian wrt (\mu,\mu) of the entropy

Source code in `cupid_matching/choo_siow.py`

    199
    200
    201
    202
    203
    204
    205
    206
    207
    208
    209
    210
    211
    212
    213
    214
    215
    216
    217
    218
    219
    220
    221
    222
    def hessian_mumu_choo_siow_corrected(muhat: Matching) -> ThreeArrays:
        """Returns the derivatives of $e_0$ in $\\mu$
        for the Choo and Siow model, with the small sample correction

        Args:
            muhat: a Matching

        Returns:
            the three components of the hessian wrt $(\\mu,\\mu)$ of the entropy
        """
        _, hessmumu, _ \
            = _der_entropy_choo_siow_corrected(muhat, hessian=True)
        muxy, *_ = muhat.unpack()
        X, Y = muxy.shape
        hess_x = np.zeros((X, Y, Y))
        hess_y = np.zeros((X, Y, X))
        hess_xy = np.zeros((X, Y))
        for x in range(X):
            for y in range(Y):
                d2xy = hessmumu[x, y, :, :]
                hess_x[x, y, :] = d2xy[x, :]
                hess_y[x, y, :] = d2xy[:, y]
                hess_xy[x, y] = d2xy[x, y]
        return hess_x, hess_y, hess_xy

## `hessian_mur_choo_siow(muhat)`

Returns the derivatives of e_0
in r
for the Choo and Siow model.

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`TwoArrays` | the two components of the hessian wrt (\mu,r) of the entropy

Source code in `cupid_matching/choo_siow.py`

    225
    226
    227
    228
    229
    230
    231
    232
    233
    234
    235
    236
    237
    238
    239
    240
    241
    242
    243
    244
    245
    246
    def hessian_mur_choo_siow(muhat: Matching) -> TwoArrays:
        """Returns the derivatives of $e_0$ in $r$
        for the Choo and Siow model.

        Args:
            muhat: a Matching

        Returns:
            the two components of the hessian wrt $(\\mu,r)$ of the entropy
        """
        entropy_res = _entropy_choo_siow(muhat, deriv=2)
        hessmur = entropy_res[3]
        muxy, *_ = muhat.unpack()
        X, Y = muxy.shape
        hess_nx = np.zeros((X, Y))
        hess_my = np.zeros((X, Y))
        for x in range(X):
            for y in range(Y):
                d2r = hessmur[x, y, :]
                hess_nx[x, y] = d2r[x]
                hess_my[x, y] = d2r[X + y]
        return hess_nx, hess_my

## `hessian_mur_choo_siow_corrected(muhat)`

Returns the derivatives of e_0
in r
for the Choo and Siow model, with the small sample correction

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`TwoArrays` | the two components of the hessian wrt (\mu,r) of the entropy

Source code in `cupid_matching/choo_siow.py`

    249
    250
    251
    252
    253
    254
    255
    256
    257
    258
    259
    260
    261
    262
    263
    264
    265
    266
    267
    268
    269
    270
    def hessian_mur_choo_siow_corrected(muhat: Matching) -> TwoArrays:
        """Returns the derivatives of $e_0$ in $r$
        for the Choo and Siow model, with the small sample correction

        Args:
            muhat: a Matching

        Returns:
            the two components of the hessian wrt $(\\mu,r)$ of the entropy
        """
        _, _, hessmur \
            = _der_entropy_choo_siow_corrected(muhat, hessian=True)
        muxy, *_ = muhat.unpack()
        X, Y = muxy.shape
        hess_nx = np.zeros((X, Y))
        hess_my = np.zeros((X, Y))
        for x in range(X):
            for y in range(Y):
                d2r = hessmur[x, y, :]
                hess_nx[x, y] = d2r[x]
                hess_my[x, y] = d2r[X + y]
        return hess_nx, hess_my